/*
	@name Blinky
	     STM32VLDISCOVERY
	  GPIO PC8  PC9   FWLib

*/

#include "stm32f10x_lib.h"				// Enable FWLib 

#define GPIO_LED                   GPIOC
#define RCC_APB2Periph_GPIO_LED    RCC_APB2Periph_GPIOC

/* Private function prototypes -----------------------------------------------*/
void Delay(void);
void RCC_Configuration(void);
void NVIC_Configuration(void);
void GPIO_Configuration(void);
void TIM_Configuration(void);
void TIM2_IRQHandler(void);


/*----------------------------------------------------------------------------
   Enable periferial clocks
 *----------------------------------------------------------------------------*/
void RCC_Configuration(void)
{
 /* Enable GPIO_LED clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIO_LED, ENABLE);

  /* Enable TIM2 clocks */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
}

/*----------------------------------------------------------------------------
   GPIO LED pins setting
 *----------------------------------------------------------------------------*/
void GPIO_Configuration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  /* Configure GPIO_LED pin 8, GPIO_LED pin 9 as output push-pull */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIO_LED, &GPIO_InitStructure);
  GPIO_ResetBits(GPIO_LED, GPIO_Pin_8);
  GPIO_ResetBits(GPIO_LED, GPIO_Pin_9);
}


/*----------------------------------------------------------------------------
   TIM2 NVIC enable Interrupt
 *----------------------------------------------------------------------------*/
void NVIC_Configuration(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;
  
  /* Set the Vector Table base location at 0x08000000 */
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);

 /* Configure one bit for preemption priority */
  NVIC_PriorityGroupConfig(NVIC_PriorityGroup_2);

  /* Enable the TIM2 gloabal Interrupt */
  NVIC_InitStructure.NVIC_IRQChannel = TIM2_IRQChannel;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

  NVIC_Init(&NVIC_InitStructure);
}
/*----------------------------------------------------------------------------
  TIM2 Configuration
 *----------------------------------------------------------------------------*/
void TIM_Configuration(void)
{
  TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
  TIM_OCInitTypeDef  TIM_OCInitStructure;

  /* TIM2 configuration */
  TIM_TimeBaseStructure.TIM_Period = 10000;          
  TIM_TimeBaseStructure.TIM_Prescaler = 2399;       
  TIM_TimeBaseStructure.TIM_ClockDivision = 0x0;    
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;  
  TIM_TimeBaseStructure.TIM_RepetitionCounter = 0x0000;
  TIM_TimeBaseInit(TIM2, &TIM_TimeBaseStructure);
  
  TIM_OCStructInit(&TIM_OCInitStructure);

  /* Output Compare Timing Mode configuration: Channel1 */
//  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_Timing;                   
//  TIM_OCInitStructure.TIM_Pulse = 0x0;  
//  TIM_OC1Init(TIM2, &TIM_OCInitStructure);  
     
  /* TIM2 enable counter */
  TIM_Cmd(TIM2, ENABLE);

  /* Immediate load of TIM2 Precaler value */
  TIM_PrescalerConfig(TIM2, 2399, TIM_PSCReloadMode_Immediate);

  /* Enable TIM2 Update interrupt */
  TIM_ITConfig(TIM2, TIM_IT_Update, ENABLE);
   
  /* Clear TIM2 update pending flag */
  TIM_ClearFlag(TIM2, TIM_FLAG_Update);

  /* In DEBUG Mode Stop the Timer2 */
//  DBGMCU->CR |= DBGMCU_TIM2_STOP;   
}

/*----------------------------------------------------------------------------
  TIM2 Interrupt Handler
 *----------------------------------------------------------------------------*/
void TIM2_IRQHandler(void)
{
  static int Led = 0x00000000;

  /* Clear TIM2 update interrupt */
  TIM_ClearITPendingBit(TIM2, TIM_IT_Update);

  if (Led) 
     {
	   GPIO_ResetBits(GPIO_LED, GPIO_Pin_8);
	   GPIO_SetBits(GPIO_LED, GPIO_Pin_9);
       Led = 0x00000000;
	 }
     else     
	 {
	   GPIO_ResetBits(GPIO_LED,GPIO_Pin_9);
	   GPIO_SetBits(GPIO_LED, GPIO_Pin_8);
	   Led = 0x00000001;
	 }
}
 
int main(void)
{
RCC_Configuration();
GPIO_Configuration();
TIM_Configuration();
NVIC_Configuration();
 
while(1)
	{

	}
 } 


